rai\_toolbox.mushin.MultiRunMetricsWorkflow
===========================================

.. currentmodule:: rai_toolbox.mushin

.. autoclass:: MultiRunMetricsWorkflow

   
   .. automethod:: __init__
   .. automethod:: pre_task
   .. automethod:: task
   .. automethod:: run
   .. automethod:: load_from_dir
   .. automethod:: load_metrics
   .. automethod:: metric_load_fn
   .. automethod:: to_xarray
   .. autoproperty:: target_dir_multirun_overrides


   
   .. rubric:: Methods

   .. autosummary::
   
      ~MultiRunMetricsWorkflow.__init__
      ~MultiRunMetricsWorkflow.pre_task
      ~MultiRunMetricsWorkflow.task
      ~MultiRunMetricsWorkflow.run
      ~MultiRunMetricsWorkflow.metric_load_fn
      ~MultiRunMetricsWorkflow.load_from_dir
      ~MultiRunMetricsWorkflow.load_metrics
      ~MultiRunMetricsWorkflow.metric_load_fn
      ~MultiRunMetricsWorkflow.target_dir_multirun_overrides
      ~MultiRunMetricsWorkflow.to_xarray
      ~MultiRunMetricsWorkflow.jobs_post_process
      ~MultiRunMetricsWorkflow.plot
      ~MultiRunMetricsWorkflow.validate